@@ -15,7 +15,7 @@ from typing import Any, Callable, Iterator, Mapping, MutableMapping, Sequence, o
 
 
 class Deck(Population):
-    """EXPERIMENTAL: Sampling without replacement (within a single evaluation).
+    """Sampling without replacement (within a single evaluation).
 
     Quantities represent duplicates.
     """
@@ -51,6 +51,8 @@ class Deck(Population):
                     For example, `(d6, d6)` will expand to 36 ordered tuples
                     with dup 1 each. Use this carefully since it may create a
                     large number of outcomes.
+                * `str` or `bytes`, which will be treated as a single outcome.
+                * Any other sequence. Each element will be weighted equally.
                 * Anything else will be treated as a single outcome.
                     Each outcome must be hashable, and the
                     set of outcomes must be totally orderable (after expansion).
@@ -134,6 +136,46 @@ class Deck(Population):
         """
         return icepool.Deal(self, *hand_sizes)
 
+    def sub(self, repl: Callable | Mapping, /, star: int = 0) -> 'Deck':
+        """Changes outcomes of the `Deck` to other outcomes.
+
+        You can think of this as `sub`stituting outcomes of this `Deck` for
+        other outcomes.
+
+        Args:
+            repl: One of the following:
+                * A callable returning a new outcome for each old outcome.
+                * A map from old outcomes to new outcomes.
+                    Unmapped old outcomes stay the same.
+                The new outcomes may be `Deck`s, in which case one card is
+                replaced with several. This is not recommended.
+            star: If set to `True` or 1, outcomes of `self` will be unpacked as
+                `*outcome` before giving it to the `repl` function. `extra_dice`
+                are not unpacked. If `repl` is not a callable, this has no
+                effect.
+        """
+        # Convert to a single-argument function.
+        if callable(repl):
+            if star:
+
+                def transition_function(outcome):
+                    return repl(*outcome)
+            else:
+
+                def transition_function(outcome):
+                    return repl(outcome)
+        else:
+            # repl is a mapping.
+            def transition_function(outcome):
+                if outcome in repl:
+                    return repl[outcome]
+                else:
+                    return outcome
+
+        return Deck(
+            [transition_function(outcome) for outcome in self.outcomes()],
+            times=self.quantities())
+
     @cached_property
     def _key_tuple(self) -> tuple:
         return Deck, tuple(self.items())
