@@ -56,7 +56,7 @@ class OutcomeCountEvaluator(ABC):
     """
 
     @abstractmethod
-    def next_state(self, state: Hashable, outcome, /, *counts: int) -> Hashable:
+    def next_state(self, state: Hashable, outcome, /, *counts) -> Hashable:
         """State transition function.
 
         This should produce a state given the previous state, an outcome,
@@ -70,9 +70,13 @@ class OutcomeCountEvaluator(ABC):
 
         Make sure to handle the base case where `state is None`.
 
-        States must be hashable, but unlike outcomes they do not need to be
-        orderable. However, if they are not totally orderable, you must override
-        `final_outcome` to create legal final outcomes.
+        States must be hashable. At current, they do not have to be orderable.
+        However, this may change in the future, and if they are not totally
+        orderable, you must override `final_outcome` to create totally orderable
+        final outcomes.
+
+        The behavior of returning a `Die` from `next_state` is currently
+        undefined.
 
         Args:
             state: A hashable object indicating the state before rolling the
@@ -87,10 +91,11 @@ class OutcomeCountEvaluator(ABC):
                 may or may not be seen. If you need to enforce that certain
                 outcomes are seen even if they have zero count, see
                 `alignment()`.
-            *counts: One `int` for each generator output indicating how many of
-                the current outcome were produced. All outcomes with nonzero
-                count are guaranteed to be seen. To guarantee that outcomes
-                are seen even if they have zero count, override `alignment()`.
+            *counts: One value (usually an `int`) for each generator output
+                indicating how many of the current outcome were produced.
+                All outcomes with nonzero count are guaranteed to be seen.
+                To guarantee that outcomes are seen even if they have zero
+                count, override `alignment()`.
 
         Returns:
             A hashable object indicating the next state.
